summaryrefslogtreecommitdiffstats
path: root/src/filelist.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/filelist.h')
-rwxr-xr-xsrc/filelist.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/filelist.h b/src/filelist.h
index c2e39a6..e34dcf2 100755
--- a/src/filelist.h
+++ b/src/filelist.h
@@ -34,16 +34,16 @@ class FileListItem : public KListViewItem
public:
/**
* Constructor
* @param tqparent The tqparent list view
*/
- FileListItem( KListView* tqparent );
+ FileListItem( KListView* parent );
/**
* Constructor
* @param tqparent The tqparent list view
* @param after The item, the new item should be placed after
*/
- FileListItem( KListView* tqparent, FileListItem* after );
+ FileListItem( KListView* parent, FileListItem* after );
/**
* Destructor
@@ -90,10 +90,10 @@ class FileList : public KListView
public:
/**
* Constructor
* @param tqparent The tqparent widget
* @param name The name of the file list
*/
- FileList( CDManager*, TagEngine*, Config*, Options*, Logger*, TQWidget *tqparent = 0, const char* name = 0 );
+ FileList( CDManager*, TagEngine*, Config*, Options*, Logger*, TQWidget *parent = 0, const char* name = 0 );
/**
* Destructor
@@ -34,16 +34,16 @@ class FileListItem : public KListViewItem
/**
* Constructor
- * @param tqparent The tqparent list view
+ * @param parent The parent list view
*/
@@ -34,16 +34,16 @@ class FileListItem : public KListViewItem
/**
* Constructor
- * @param tqparent The tqparent list view
+ * @param parent The parent list view
* @param after The item, the new item should be placed after
*/
@@ -90,10 +90,10 @@ class FileList : public KListView
/**
* Constructor
- * @param tqparent The tqparent widget
+ * @param parent The parent widget
* @param name The name of the file list
*/